# jws-tools-vue

#### 介绍
vue网页快速开发工具包

#### 运行环境
vue-cli


#### 安装教程

```shell
npm install jws-tools-vue -S
```

#### 使用说明

##### 1)、数据缓存（useGlobalState）

```javascript
const { useGlobalState } = require('jws-tools-vue');
//调用方法，返回 读取、写入的方法
const [getState, setState] = useGlobalState(defaultState, key, options);
```

**参数**

| 属性         | 类型   | 默认值 | 必填 | 说明     |
| ------------ | ------ | ------ | ---- | -------- |
| defaultState | any    | null   | 否   | 默认值   |
| key          | string |        | 是   | 唯一标识 |
| options      | object |        | 否   | 配置     |

**options**

| 属性           | 类型   | 默认值 | 必填 | 说明                                 |
| -------------- | ------ | ------ | ---- | ------------------------------------ |
| storage        | string | null   | 否   | 缓存方式 ['local']                   |
| storageTimeout | number | 0      | 否   | 过期时间，当storage=local，0表示永久 |

**使用**

```javascript
const { useGlobalState } = require('jws-tools-vue');
const [getAuthToken, setAuthToken] = useGlobalState("AUTHTOKEN", {
  storage: "local"
});
//写入
setAuthToken('wx3da7ad15540aa97d');
//获取
const token = getAuthToken();
```



##### 2)、封装Api（ApiGenerator）

```javascript
const { ApiGenerator} = require('jws-tools-vue');
//返回生成Api的方法
const { genApi,setApiConfig } = new ApiGenerator(serverUrl,cusRequest);
//配置
const config = {
  //拦截器
  interceptors: (options) => {
    console.log("拦截到请求==", options);
  },
  //异常处理
  onError: (error) => {
    console.log("请求错误==", error);
  },
  ...
};
setApiConfig(config);
// 构建
const userApi = genApi(API);
//模块化
module.exports = {
  userApi
}
```

**ApiGenerator 参数**

| 属性       | 类型     | 默认值 | 必填 | 说明                                  |
| ---------- | -------- | ------ | ---- | ------------------------------------- |
| serverUrl  | string   |        | 是   | 接口前缀                              |
| cusRequest | function |        | 否   | http请求方法，必须返回一个Promise对象 |

**setApiConfig  参数 config**

| 属性         | 类型     | 默认值 | 必填 | 说明                           |
| ------------ | -------- | ------ | ---- | ------------------------------ |
| interceptors | function |        | 否   | 拦截器，发送请求前可以修改参数 |
| onError      | function |        | 否   | 异常处理                       |
| format       | function |        | 否   | 对返回的数据进行格式化         |
| headers      | object   |        | 否   | 默认的header参数               |
| params       | object   |        | 否   | 默认的data参数                 |

**genApi 参数 API  （Object object）**

```javascript
const API = {
  //登录
  login: 'POST /auth/login',
  //获取签到记录
  getSignDataList: {
    url: '/getSignDataList',
    method: 'POST',
    headers: {
      'content-type': 'application/x-www-form-urlencoded'
    }
  }
}
```

**使用**

```javascript
//引入封装的Api
const { userApi } = require('../../../api/index');
//调用接口
userApi.getSignDataList({page:1,pageSize:20}).then((res) => {
      console.log("签到记录=", res);
    })
```





##### 3)、表单验证（form）

**form.validate 参数**

| 属性     | 类型   | 默认值 | 必填 | 说明       |
| -------- | ------ | ------ | ---- | ---------- |
| formData | object |        | 是   | 提交的数据 |
| rules    | object |        | 是   | 验证规则   |

**使用**

```javascript
const { form } = require('jws-tools-vue');
/**
*表单提交方法
**/
formSubmit(e) {
    let formData = e.detail.value;
    form.validate(formData, {
      name: "姓名为必填项",
      age: (val) => {
        if ("验证失败") {
          return '年龄必须大于18岁'
        }
        return false; //返回空，表示验证通过
      }
    });
 }
```

##### 4)、常用方法（util）

```javascript
const { util } = require('jws-tools-vue');
```

###### **util.isEmpty(value)**

判断当前value值是否为空

**参数**

| 属性  | 类型 | 默认值 | 必填 | 说明            |
| ----- | ---- | ------ | ---- | --------------- |
| value | any  |        | 否   | 不填，返回false |

**返回值**

Boolean(true/false)

```javascript
let status = util.isEmpty(this.userInfo);
```



###### **util.formatTime(datetime,fmt)**

对日期进行格式化

**参数**

| 属性     | 类型               | 默认值              | 必填 | 说明 |
| -------- | ------------------ | ------------------- | ---- | ---- |
| datetime | date/string/number | 当前时间            | 否   |      |
| fmt      | string             | yyyy-MM-dd hh:mm:ss | 否   |      |

**返回值**

String

```javascript
let datetime = new Date();
datetime = util.formatTime(datetime, "yyyy-MM-dd hh:mm");
```







#### 参与贡献

1.  Fork 本仓库
2.  新建 Feat_xxx 分支
3.  提交代码
4.  新建 Pull Request

6.  https://gitee.com/gitee-stars/)
